import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.core._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-codestarconnections", "1.43.0", __name__[0:-6], "aws-codestarconnections@1.43.0.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
